@@ -33,7 +33,7 @@ test_that("TunerGridSearch works with forward hotstart parameter", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     store_models = TRUE,
     allow_hotstart = TRUE,
     batch_size = 5,
@@ -55,7 +55,7 @@ test_that("TunerGridSearch works with forward hotstart parameter", {
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     store_models = TRUE,
     allow_hotstart = TRUE,
     batch_size = 5,
@@ -77,7 +77,7 @@ test_that("TunerGridSearch works with forward and backward hotstart parameter",
     task = task,
     learner = learner,
     resampling = rsmp("holdout"),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     store_models = TRUE,
     allow_hotstart = TRUE,
     batch_size = 5,
